//============================================================================
// FILE: C_CoreMonitor.h
//
// TYPE: C++CLASS
// DESCRIPTION: entête des démons de Control-Diese
// 
// AUTHORS: Rellier (INRA/UBIA, Toulouse)
// REFERENCE : "Fondements ontologiques des systèmes pilotés"
//             R. Martin-Clouaire, J.-P. Rellier (INRA/UBIA, Toulouse)
//=X===============X=============================X============================

#ifndef _C_COREMONITOR_HH
#define _C_COREMONITOR_HH

// SYSTEM INCLUDES
//

// PROJECT INCLUDES
//
#include "DescValueMonitor.h"
//#include "StructureMonitor.h"


/**@name Les démons prédéfinis */
//@{

/**@name Fonction d'installation */
//@{
        /// Cette fonction est appelée en début du programme principal, pour que les démons prédéfinis dans \CDb soient actifs dès le début de la période simulée. Cet appel est automatiquement réalisé si l'initialisation de la simulation est faite dans un fichier de spécifications de la simulation lu par un appel à {\bf C\_ParseSimulationFile} (voir page \pageref{simulationFile}).
void C_DefineMonitors();
//@}

//X///////////////X/////////////////////////////X////////////////////////////

// EXTERNAL REFERENCES

/**@name Démons sur la structure */
//@{
        //
BasicEntity* singleStockElementTab_whenAddElement_Body(MonitorMethod* pM);
        //
BasicEntity* singleStockElementTab_whenRemoveElement_Body(MonitorMethod* pM);
        /// Moniteur posé sur la liste des élément de la classe {\bf SingleStock}. Les méthodes {\bf WhenAddElement} et {\bf WhenRemoveElement} peuvent être surchargées en invoquant respectivement {\tt singleStockElementTab_whenAddElement_Body(MonitorMethod* pM)} et {\tt singleStockElementTab_whenRemoveElement_Body(MonitorMethod* pM)} en préambule de la fonction correspondante de l'application.\index{SingleStockElementTabMonitor}
extern StructureMonitor* SingleStockElementTabMonitor;
        //
extern StructureMonitor* NonPrimitiveActivityElementTabMonitor;
//@}

//---------------------------------------------------------------------------
/**@name Démons sur les descripteurs */
//@{
        //
int activityReadyToRun_whenSetInt_Body(MonitorMethod* pM);
        /// Moniteur posé sur le descripteur {\bf ReadyToRun} de la classe {\bf Activity}. La méthode {\bf WhenSetInt} peut être surchargée en invoquant {\tt activityReadyToRun_whenSetInt_Body(MonitorMethod* pM)} en préambule de la fonction correspondante de l'application.\index{ActivityReadyToRunMonitor}
extern IntDescValueMonitor* ActivityReadyToRunMonitor;
        //
extern EntityDescValueMonitor* PrimitiveActivitySpecificationMonitor;
        //
extern EntityDescValueMonitor* PrimitiveActivityOperationSpecificationMonitor;
        //
int operationSituation_whenSetInt_Body(MonitorMethod* pM);
        /// Moniteur posé sur le descripteur {\bf Situation} de la classe {\bf Operation}. La méthode {\bf WhenSetInt} peut être surchargée en invoquant {\tt operationSituation_whenSetInt_Body(MonitorMethod* pM)} en préambule de la fonction correspondante de l'application.\index{OperationSituationMonitor}
extern IntDescValueMonitor* OperationSituationMonitor;
        //
extern FloatDescValueMonitor* OperationActivityClosingThresholdMonitor;
        //
float operationPercentAchieved_whenSetFloat_Body(MonitorMethod* pM);
        /// Moniteur posé sur le descripteur {\bf PercentAchieved} de la classe {\bf Operation}. La méthode {\bf WhenSetFloat} peut être surchargée en invoquant {\tt operationPercentAchieved_whenSetFloat_Body(MonitorMethod* pM)} en préambule de la fonction correspondante de l'application.\index{OperationPercentAchievedMonitor}
extern FloatDescValueMonitor* OperationPercentAchievedMonitor;
        //
extern EntityTabDescValueMonitor* OperationRequiredResourcesMonitor;

        //
extern IntDescValueMonitor* CoengagementItemResourceIdMonitor;

        //
extern IntDescValueMonitor* ActivityMinBegDateMonitor;
        //
extern IntDescValueMonitor* ActivityMaxBegDateMonitor;
        //
extern IntDescValueMonitor* ActivityMinEndDateMonitor;
        //
extern IntDescValueMonitor* ActivityMaxEndDateMonitor;
        //
extern IntDescValueMonitor* PrimitiveActivityOperationClassIdMonitor;
        //
extern StringDescValueMonitor* PrimitiveActivityOperationClassNameMonitor;

        //
extern IntDescValueMonitor* ActivityIterationMinNumberOfReplicationsMonitor;
        //
extern IntDescValueMonitor* ActivityIterationMaxNumberOfReplicationsMonitor;
        //
int resourceAvailabilityStatus_whenSetInt_Body(MonitorMethod* pM);
        /// Moniteur posé sur le descripteur {\bf AvailabilityStatus} de la classe {\bf Resource}. La méthode {\bf WhenSetInt} peut être surchargée en invoquant {\tt resourceAvailabilityStatus_whenSetInt_Body(MonitorMethod* pM)} en préambule de la fonction correspondante de l'application.\index{ResourceAvailabilityStatusMonitor}
extern IntDescValueMonitor* ResourceAvailabilityStatusMonitor;
        //
extern IntDescValueMonitor* OperatedObjectAvailabilityStatusMonitor;

        //
extern IntDescValueMonitor* SpecificationReferenceClassIdMonitor;
        //
extern StringDescValueMonitor* SpecificationReferenceClassNameMonitor;
        //
extern EntityDescValueMonitor* SpecificationReferentEntityMonitor;
        //
extern IntDescValueMonitor* SpecificationOperationClassIdMonitor;
        //
extern StringDescValueMonitor* SpecificationOperationClassNameMonitor;

        //
int integerStockCapacityIntCurrentLevel_whenSetInt_Body(MonitorMethod* pM);
        /// Moniteur posé sur le descripteur {\bf IntCurrentLevel} de la classe {\bf IntegerStockCapacity}. La méthode {\bf WhenSetInt} peut être surchargée en invoquant {\tt integerStockCapacityIntCurrentLevel_whenSetInt_Body(MonitorMethod* pM)} en préambule de la fonction correspondante de l'application.\index{IntegerStockCapacityIntCurrentLevelMonitor}
extern IntDescValueMonitor* IntegerStockCapacityIntCurrentLevelMonitor;
        //
float floatStockCapacityFloatCurrentLevel_whenSetFloat_Body(MonitorMethod* pM);
        /// Moniteur posé sur le descripteur {\bf FloatCurrentLevel} de la classe {\bf FloatStockCapacity}. La méthode {\bf WhenSetFloat} peut être surchargée en invoquant {\tt floatStockCapacityFloatCurrentLevel_whenSetFloat_Body(MonitorMethod* pM)} en préambule de la fonction correspondante de l'application.\index{FloatStockCapacityFloatCurrentLevelMonitor}
extern FloatDescValueMonitor* FloatStockCapacityFloatCurrentLevelMonitor;

        //
extern EntityTabDescValueMonitor* PrimitiveActivityGoalListMonitor;

        //
extern FloatDescValueMonitor* CriterionWeightMonitor;
        //
extern FloatDescValueMonitor* CriterionSetWeightMonitor;

        //
extern IntDescValueMonitor* GoalActivityActionModeMonitor;

        //
extern EntityDescValueMonitor* TransferActivityInformationMonitor;

        //
extern IntDescValueMonitor* InconsistencyConditionEntityClassIdMonitor;
//@}  // fin démons descripteurs

//@}  // fin démons
//---------------------------------------------------------------------------

#endif  // _C_COREMONITOR_HH
