//============================================================================
// FILE: C_Strategy.h
//
// TYPE: C++CLASS
// DESCRIPTION: entête des éléments de la stratégie
// 
// AUTHORS: Rellier (INRA/UBIA, Toulouse)
// REFERENCE : "Fondements ontologiques des systèmes pilotés"
//             R. Martin-Clouaire, J.-P. Rellier (INRA/UBIA, Toulouse)
//=X===============X=============================X============================

#ifndef _C_STRATEGY_HH
#define _C_STRATEGY_HH

// SYSTEM INCLUDES
//

// PROJECT INCLUDES
//
#include "C_CoreTypes.h"

// EXTERNAL REFERENCES 


//===========================================================================
//
// STRATEGY
//
//===========================================================================

/**@name Les stratégies de conduite
\label{classeStrategy}
\begin{itemize} \item Directive d'inclusion : {\tt \#include C\_Strategy.h} \end{itemize}
Une {\em stratégie de conduite}\index{stratégie de conduite} est un ensemble de spécifications et de règles d'action que suit le gestionnaire (au sens technique) d'un {\em système contrôlé} pour atteindre un certain objectif.\\

La stratégie de conduite du système est, avec la configuration même du système, un des deux éléments de la stratégie (au sens large) du gestionnaire. La configuration du système ne fait donc pas partie de la stratégie de conduite (au sens strict).\\

Les trois composants d'une stratégie sont :
\begin{itemize}
\item Une {\em trajectoire réactive}, qui est un ensemble de {\em points d'ajustement} de la stratégie elle-même, et plus particulièrement des plans d'activités contenus dans la stratégie.
\item Un ensemble de {\em blocs activités-ressources}. Chaque élément de cet ensemble est lui-même un assemblage de {\em plans}\index{plan} d'action.
\item Un ensemble de {\em règles de préférence}. 
\end{itemize}
*/
//@{

/**@name La classe des stratégies de conduite */
//@{
          ///
//----------------------------------------------------------------------------
class Strategy : public Entity
{
public:

  /**@name LIFECYCLE */
//@{
          // Constructeur de base.
Strategy();
          /// Constructeur par copie profonde. 
Strategy(const Strategy&); 
          /// Destructeur superficiel. Utiliser {\bf DeleteInDepth} (classe {\bf Entity} de \D) pour une destruction en profondeur.
~Strategy();
          /// Destructeur en profondeur de la stratégie et de ses composants.\index{méthodes!DeleteInDepth}
void DeleteInDepth();
//@}

/**@name  ACCESS */
//@{
           /// Renvoie le système  contrôlé par la présente stratégie.\index{méthodes!GetCS -Strategy-}
  ControlledSystem* GetCS();
//@} 

protected: 

private:
};
 
//@}  // fin classe stratégie  
 
//===========================================================================
//
// ACTIVITIES_RESOURCES_BLOCKSET
//
//===========================================================================

/**@name Ensembles de blocs activités-ressources
\begin{itemize} \item Directive d'inclusion : {\tt \#include C\_Strategy.h} \end{itemize}
*/ 
//@{
          ///
class ActivitiesResourcesBlockSet : public Entity
{
public:
          // Constructeur de base.
   ActivitiesResourcesBlockSet();
          // Constructeur par copie.
   ActivitiesResourcesBlockSet(const ActivitiesResourcesBlockSet&);
          // Destructeur.
   ~ActivitiesResourcesBlockSet();

/**@name  ACCESS */
//@{
//@}  
 };
 
//@}  // fin arbet


//===========================================================================
//
// ACTIVITIES_RESOURCES_BLOCK
//
//===========================================================================

/**@name Blocs activités-ressources
\begin{itemize} \item Directive d'inclusion : {\tt \#include C\_Strategy.h} \end{itemize}
*/ 
//@{
          ///
class ActivitiesResourcesBlock : public Entity
{
public:
          // Constructeur de base.
   ActivitiesResourcesBlock();
          // Constructeur par copie.
   ActivitiesResourcesBlock(const ActivitiesResourcesBlock&);
          // Destructeur.
   ~ActivitiesResourcesBlock();
 }; 
 
//@}  // fin arb


//@}  // fin stratégies

#endif  // _C_STRATEGY_HH
